package DB;

import Objects.Cottage;
import Objects.Owner;

import javax.swing.*;
import java.sql.*;
import java.util.ArrayList;
import java.util.List;

public class Request {
    public static Owner getOwner(String lastName, String zip) {
        Owner owner = null;
        Connection c = Connexion.getConnexion();
        try {
            PreparedStatement ps = c.prepareStatement("SELECT IDPROPRIO, PRENOMPROPRIO, NOMPROPRIO, ADPROPRIO, CPPROPRIO, VILLEPROPRIO FROM PROPRIETAIRE WHERE NOMPROPRIO = ? AND CPPROPRIO = ?");
            ps.setString(1, lastName);
            ps.setString(2, zip);
            if (ps.execute()) {
                ResultSet rs = ps.getResultSet();
                if (rs.next())
                    owner = new Owner(rs.getInt("IDPROPRIO"),
                            rs.getString("PRENOMPROPRIO"),
                            rs.getString("NOMPROPRIO"),
                            rs.getString("ADPROPRIO"),
                            rs.getString("CPPROPRIO"),
                            rs.getString("VILLEPROPRIO"));
            }
            ps.close();
            c.close();
        } catch (SQLException e) {
            System.err.println(e);
            JOptionPane.showMessageDialog(null, "Error when query owner !");
        }
        return owner;
    }

    public static List<Cottage> getCottages(Owner owner) {
        List<Cottage> cottages = new ArrayList<>();
        Connection c = Connexion.getConnexion();
        try {
            PreparedStatement ps = c.prepareStatement("SELECT IDGITE, NOMGITE, ADGITE, CPGITE, VILLEGITE, NBPLACES, NBCHAMBRES, SURFACE, PRIX FROM GITE WHERE IDPROPRIO = ? ORDER BY IDGITE");
            ps.setInt(1, owner.getId());
            if (ps.execute()) {
                for (ResultSet rs = ps.getResultSet(); rs.next(); )
                    cottages.add(new Cottage(rs.getInt("IDGITE"),
                            rs.getString("NOMGITE"),
                            rs.getString("ADGITE"),
                            rs.getString("CPGITE"),
                            rs.getString("VILLEGITE"),
                            rs.getInt("NBPLACES"),
                            rs.getInt("NBCHAMBRES"),
                            rs.getInt("SURFACE"),
                            rs.getInt("PRIX"),
                            owner));
            }
            ps.close();
            c.close();
        } catch (SQLException e) {
            System.err.println(e);
            JOptionPane.showMessageDialog(null, "Error when query cottages !");
        }
        return cottages;
    }

    public static boolean deleteCottage(Cottage cottage) {
        Connection c = Connexion.getConnexion();
        try {
            PreparedStatement ps = c.prepareStatement("DELETE FROM GITE WHERE IDGITE = ?");
            ps.setInt(1, cottage.getId());
            int res = ps.executeUpdate();
            ps.close();
            c.close();
            return res == 1;
        } catch (SQLException e) {
            System.err.println(e);
            JOptionPane.showMessageDialog(null, "Error when delete cottage !");
        }
        return false;
    }

    public static Cottage addCottage(String name, String address, String zip, String city, int numberPlaces, int numberBedrooms, int area, int price, Owner owner) {
        Connection c = Connexion.getConnexion();
        try {
            Statement s = c.createStatement();
            int id;
            if (s.execute("SELECT max(IDGITE) FROM GITE")) {
                ResultSet rs = s.getResultSet();
                rs.next();
                id = rs.getInt(1) + 1;
                s.close();
            } else
                id = 1;

            PreparedStatement ps = c.prepareStatement("INSERT INTO GITE (IDGITE, NOMGITE, ADGITE, CPGITE, VILLEGITE, NBPLACES, NBCHAMBRES, SURFACE, PRIX, IDPROPRIO) VALUES  (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
            ps.setInt(1, id);
            ps.setString(2, name);
            ps.setString(3, address);
            ps.setString(4, zip);
            ps.setString(5, city);
            ps.setInt(6, numberPlaces);
            ps.setInt(7, numberBedrooms);
            ps.setInt(8, area);
            ps.setInt(9, price);
            ps.setInt(10, owner.getId());
            int res = ps.executeUpdate();
            ps.close();
            c.close();
            if (res == 1)
                return new Cottage(id, name, address, zip, city, numberPlaces, numberBedrooms, area, price, owner);
        } catch (SQLException e) {
            System.err.println(e);
            JOptionPane.showMessageDialog(null, "Error when insert cottage !");
        }
        return null;
    }

    public static boolean editCottage(Cottage cottage) {
        Connection c = Connexion.getConnexion();
        boolean res = false;
        try {
            PreparedStatement ps = c.prepareStatement("UPDATE GITE SET NOMGITE=?, ADGITE=?, CPGITE=?, VILLEGITE=?, NBPLACES=?, NBCHAMBRES=?, SURFACE=?, PRIX=? WHERE IDGITE=?");
            ps.setString(1, cottage.getName());
            ps.setString(2, cottage.getAddress());
            ps.setString(3, cottage.getZip());
            ps.setString(4, cottage.getCity());
            ps.setInt(5, cottage.getNumberPlaces());
            ps.setInt(6, cottage.getNumberBedrooms());
            ps.setInt(7, cottage.getArea());
            ps.setInt(8, cottage.getPrice());
            ps.setInt(9, cottage.getId());

            if (ps.executeUpdate() == 1)
                    res = true;
            ps.close();
            c.close();
        } catch (SQLException e) {
            System.err.println(e);
            JOptionPane.showMessageDialog(null, "Error when update cottage !");
        }
        return res;
    }
}
