package GUI;

import DB.Request;
import Objects.Cottage;
import Objects.Owner;

import javax.swing.*;
import javax.swing.text.NumberFormatter;
import java.awt.event.*;
import java.text.NumberFormat;

public class EditCottageGUI extends JDialog {
    private JPanel contentPane;
    private JButton buttonOK;
    private JButton buttonCancel;
    private JTextField nameField;
    private JTextField addressField;
    private JTextField cityField;
    private JFormattedTextField numberPlacesFormattedTextField;
    private JFormattedTextField numberBedroomsFormattedTextField;
    private JFormattedTextField areaFormattedTextField;
    private JFormattedTextField priceFormattedTextField;
    private JFormattedTextField zipFormattedTextField;
    private Owner owner;
    private Cottage cottage;
    private DefaultListModel defaultListModel;

    public EditCottageGUI(Owner owner, ListModel model) {
        this.owner = owner;
        this.defaultListModel = (DefaultListModel) model;
        creation();;
    }

    public EditCottageGUI(Owner owner, ListModel model, Cottage cottage) {
        this.owner = owner;
        this.defaultListModel = (DefaultListModel) model;
        this.cottage = cottage;
        creation();
    }

    private void creation() {
        setTitle("Add cottage");
        setLocationRelativeTo(null);
        setContentPane(contentPane);
        setModal(true);
        getRootPane().setDefaultButton(buttonOK);

        if (cottage != null) {
            nameField.setText(cottage.getName());
            addressField.setText(cottage.getAddress());
            addressField.setEnabled(false);
            zipFormattedTextField.setText(cottage.getZip());
            zipFormattedTextField.setEnabled(false);
            cityField.setText(cottage.getCity());
            cityField.setEnabled(false);
            numberPlacesFormattedTextField.setText(Integer.toString(cottage.getNumberPlaces()));
            numberBedroomsFormattedTextField.setText(Integer.toString(cottage.getNumberBedrooms()));
            areaFormattedTextField.setText(Integer.toString(cottage.getArea()));
            priceFormattedTextField.setText(Integer.toString(cottage.getPrice()));
        }
        buttonOK.addActionListener(actionEvent -> onOK());

        buttonCancel.addActionListener(actionEvent -> onCancel());

        // call onCancel() when cross is clicked
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                onCancel();
            }
        });

        // call onCancel() on ESCAPE
        contentPane.registerKeyboardAction(actionEvent -> onCancel(), KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);

        pack();
        setVisible(true);
    }

    private void onOK() {
        // add your code here
        if (cottage == null) {
            Cottage cottage = Request.addCottage(nameField.getText(),
                    addressField.getText(),
                    zipFormattedTextField.getText(),
                    cityField.getText(),
                    new Integer(numberPlacesFormattedTextField.getText()),
                    new Integer(numberBedroomsFormattedTextField.getText()),
                    new Integer(areaFormattedTextField.getText()),
                    new Integer(priceFormattedTextField.getText()),
                    owner);
            if (cottage != null) {
                defaultListModel.add(defaultListModel.size(), cottage);
                dispose();
            }
        } else {
            int index = defaultListModel.indexOf(cottage);
            if (!nameField.getText().equals(cottage.getName()))
                cottage.setName(nameField.getText());
            if (new Integer(numberPlacesFormattedTextField.getText()) != cottage.getNumberPlaces())
                cottage.setNumberPlaces(new Integer(numberPlacesFormattedTextField.getText()));
            if (new Integer(numberBedroomsFormattedTextField.getText()) != cottage.getNumberBedrooms())
                cottage.setNumberBedrooms(new Integer(numberBedroomsFormattedTextField.getText()));
            if (new Integer(areaFormattedTextField.getText()) != cottage.getArea())
                cottage.setArea(new Integer(areaFormattedTextField.getText()));
            if (new Integer(priceFormattedTextField.getText()) != cottage.getPrice())
                cottage.setPrice(new Integer(priceFormattedTextField.getText()));
            if (Request.editCottage(cottage))
                defaultListModel.set(index, cottage);
            dispose();
        }
    }

    private void onCancel() {
        dispose();
    }

    private void createUIComponents() {
        NumberFormat format = NumberFormat.getIntegerInstance();
        format.setGroupingUsed(false);
        NumberFormatter formatter = new NumberFormatter(format);
        formatter.setValueClass(Integer.class);
        formatter.setMinimum(0);
        formatter.setMaximum(Integer.MAX_VALUE);
        formatter.setAllowsInvalid(false);

        zipFormattedTextField = new JFormattedTextField(formatter);
        numberPlacesFormattedTextField = new JFormattedTextField(formatter);
        numberBedroomsFormattedTextField = new JFormattedTextField(formatter);
        areaFormattedTextField = new JFormattedTextField(formatter);
        priceFormattedTextField = new JFormattedTextField(formatter);
    }
}
