package GUI;

import DB.Request;
import Objects.Cottage;
import Objects.Owner;

import javax.swing.*;
import java.awt.event.*;

public class ListCottageGUI extends JDialog {
    private JPanel contentPane;
    private JButton exitButton;
    private JList cottageList;
    private JButton deleteButton;
    private JButton addButton;
    private JButton editButton;
    private Owner owner;

    public ListCottageGUI(Owner owner) {
        this.owner = owner;
        setTitle("List cottage");
        setLocationRelativeTo(null);
        setContentPane(contentPane);
        setModal(true);
        getRootPane().setDefaultButton(deleteButton);
        fillCottageList(owner);

        deleteButton.addActionListener(actionEvent -> onDelete());

        exitButton.addActionListener(actionEvent -> onExit());

        cottageList.addListSelectionListener(listSelectionEvent -> {
            if (!deleteButton.isEnabled())
                deleteButton.setEnabled(true);
            if (!editButton.isEnabled())
                editButton.setEnabled(true);
        });

        addButton.addActionListener(actionEvent -> new EditCottageGUI(owner, cottageList.getModel()));

        editButton.addActionListener(actionEvent -> new EditCottageGUI(owner, cottageList.getModel(), (Cottage) cottageList.getSelectedValue()));

        // call onCancel() when cross is clicked
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                onExit();
            }
        });

        // call onCancel() on ESCAPE
        contentPane.registerKeyboardAction(actionEvent -> onExit(), KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
        pack();
        setVisible(true);
    }

    private void onDelete() {
        // add your code here
        Cottage cottage = (Cottage) cottageList.getSelectedValue();
        if (JOptionPane.showConfirmDialog(null, "Do you want to remove " + cottage.getName() + " ?", "Remove a cottage", JOptionPane.YES_NO_OPTION) == 0)
            if (Request.deleteCottage(cottage))
                ((DefaultListModel) cottageList.getModel()).remove(cottageList.getSelectedIndex());
    }

    private void onExit() {
        // add your code here if necessary
        dispose();
    }

    private void fillCottageList(Owner owner) {
        DefaultListModel listModel = new DefaultListModel();
        for (Cottage c: Request.getCottages(owner))
            listModel.addElement(c);

        cottageList.setModel(listModel);
    }
}
